﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Globalization;

namespace SLConverter
{
    public class CustomLengthConverter : TypeConverter
    {
        //返回一个值，该值指示类型转换器能否将指定类型的对象转换为此转换器的类型
        public override bool CanConvertFrom(ITypeDescriptorContext context, Type sourceType)
        {
            if (sourceType == typeof(string))
            {
                return true;
            }
            return base.CanConvertFrom(context, sourceType);
        }
        //从指定值转换为此转换器的预期转换类型。
        public override object ConvertFrom(ITypeDescriptorContext context, CultureInfo culture, object value)
        {

            if (value == null)
            {
                return new Double();
            }
            if (value is string)
            {
                string s = (string)value;
                if (s.Length == 0)
                {
                    return new Double();
                }
                //将流入的字符串分割为两部分，使用第一部分2cm*40=80=设置的像素
                string[] arguments = s.Split(' ');
                if (arguments.Length != 2)
                {
                    return new Double();
                }
                else
                {
                    //假设1cm=40px
                    return InternalParseInput((double.Parse(arguments[0])*40).ToString());
                }
            }

            return base.ConvertFrom(context, culture, value);
        }
        //将String数据格式化为Double类型数据返回给属性
        public Double InternalParseInput(String inputString)
        {
            Double doubleValue;

            try
            {
                doubleValue = Double.Parse(inputString);
            }
            catch (Exception)
            {
                doubleValue = new Double();
            }

            return doubleValue;
        }
    }

}
